#ifndef JX_UART_SEND_H_
#define JX_UART_SEND_H_

#ifdef __cplusplus
extern "C" {
#endif

// 串口发送消息最大长度
#define UART_SEND_MAX      32
#define UART_MSG_HEAD_LEN_UART2_RX  2
#define UART_MSG_FOOT_LEN_UART2_RX  2

// 串口发送消息号
#define U_MSG_com1      1
#define U_MSG_com2      2
#define U_MSG_com3      3
#define U_MSG_com4      4
#define U_MSG_com5      5
#define U_MSG_com6      6
#define U_MSG_com7      7
#define U_MSG_com8      8
#define U_MSG_com9      9
#define U_MSG_com10      10

// 串口消息参数类型
typedef union {
  double d_double;
  int d_int;
  unsigned char d_ucs[8];
  char d_char;
  unsigned char d_uchar;
  unsigned long d_long;
  short d_short;
  float d_float;
}uart_param_t;

// 十六位整数转32位整数
void _int16_to_int32(uart_param_t* param) {
  if (sizeof(int) >= 4)
    return;
  unsigned long value = param->d_long;
  unsigned long sign = (value >> 15) & 1;
  unsigned long v = value;
  if (sign)
    v = 0xFFFF0000 | value;
  uart_param_t p;
  p.d_long = v;
  param->d_ucs[0] = p.d_ucs[0];
  param->d_ucs[1] = p.d_ucs[1];
  param->d_ucs[2] = p.d_ucs[2];
  param->d_ucs[3] = p.d_ucs[3];
}

// 浮点数转双精度 
void _float_to_double(uart_param_t* param) {
  if (sizeof(int) >= 4)
    return;
  unsigned long value = param->d_long;
  unsigned long sign = value >> 31;
  unsigned long M = value & 0x007FFFFF;
  unsigned long e =  ((value >> 23 ) & 0xFF) - 127 + 1023;
  uart_param_t p0, p1;  
  p1.d_long = ((sign & 1) << 31) | ((e & 0x7FF) << 20) | (M >> 3);
  p0.d_long = (M & 0x7) << 29;
  param->d_ucs[0] = p0.d_ucs[0];
  param->d_ucs[1] = p0.d_ucs[1];
  param->d_ucs[2] = p0.d_ucs[2];
  param->d_ucs[3] = p0.d_ucs[3];
  param->d_ucs[4] = p1.d_ucs[0];
  param->d_ucs[5] = p1.d_ucs[1];
  param->d_ucs[6] = p1.d_ucs[2];
  param->d_ucs[7] = p1.d_ucs[3];
}

// action: com1
void _uart_com1(int dint, double dfloat);

// action: com2
void _uart_com2();

// action: com3
void _uart_com3();

// action: com4
void _uart_com4();

// action: com5
void _uart_com5();

// action: com6
void _uart_com6();

// action: com7
void _uart_com7();

// action: com8
void _uart_com8();

// action: com9
void _uart_com9();

// action: com10
void _uart_com10();

#ifdef __cplusplus
}
#endif

#endif /*JX_UART_SEND_H_*/

